@@ -1,56 +1,57 @@
-import attr
+from dataclasses import dataclass
+from dataclasses import field
+from typing import Iterable
 
 from openapi_core.exceptions import OpenAPIError
 
 
 class UnmarshalError(OpenAPIError):
     """Schema unmarshal operation error"""
-    pass
 
 
 class ValidateError(UnmarshalError):
     """Schema validate operation error"""
-    pass
 
 
 class UnmarshallerError(UnmarshalError):
     """Unmarshaller error"""
-    pass
 
 
-@attr.s(hash=True)
+@dataclass
 class InvalidSchemaValue(ValidateError):
-    value = attr.ib()
-    type = attr.ib()
-    schema_errors = attr.ib(factory=tuple)
+    value: str
+    type: str
+    schema_errors: Iterable[Exception] = field(default_factory=list)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return (
             "Value {value} not valid for schema of type {type}: {errors}"
         ).format(value=self.value, type=self.type, errors=self.schema_errors)
 
 
-@attr.s(hash=True)
+@dataclass
 class InvalidSchemaFormatValue(UnmarshallerError):
     """Value failed to format with formatter"""
-    value = attr.ib()
-    type = attr.ib()
-    original_exception = attr.ib()
 
-    def __str__(self):
+    value: str
+    type: str
+    original_exception: Exception
+
+    def __str__(self) -> str:
         return (
             "Failed to format value {value} to format {type}: {exception}"
         ).format(
-            value=self.value, type=self.type,
+            value=self.value,
+            type=self.type,
             exception=self.original_exception,
         )
 
 
-@attr.s(hash=True)
+@dataclass
 class FormatterNotFoundError(UnmarshallerError):
     """Formatter not found to unmarshal"""
-    type_format = attr.ib()
 
-    def __str__(self):
-        return "Formatter not found for {format} format".format(
-            format=self.type_format)
+    type_format: str
+
+    def __str__(self) -> str:
+        return f"Formatter not found for {self.type_format} format"
