@@ -4,8 +4,7 @@ from __future__ import annotations
 from dataclasses import dataclass
 from dataclasses import field
 from typing import Any
-from typing import Dict
-from typing import Optional
+from typing import Mapping
 
 from werkzeug.datastructures import Headers
 from werkzeug.datastructures import ImmutableMultiDict
@@ -28,14 +27,10 @@ class RequestParameters:
             Path parameters as dict. Gets resolved against spec if empty.
     """
 
-    query: ImmutableMultiDict[str, Any] = field(
-        default_factory=ImmutableMultiDict
-    )
-    header: Headers = field(default_factory=Headers)
-    cookie: ImmutableMultiDict[str, Any] = field(
-        default_factory=ImmutableMultiDict
-    )
-    path: dict[str, Any] = field(default_factory=dict)
+    query: Mapping[str, Any] = field(default_factory=ImmutableMultiDict)
+    header: Mapping[str, Any] = field(default_factory=Headers)
+    cookie: Mapping[str, Any] = field(default_factory=ImmutableMultiDict)
+    path: Mapping[str, Any] = field(default_factory=dict)
 
     def __getitem__(self, location: str) -> Any:
         return getattr(self, location)
@@ -43,10 +38,10 @@ class RequestParameters:
 
 @dataclass
 class Parameters:
-    query: dict[str, Any] = field(default_factory=dict)
-    header: dict[str, Any] = field(default_factory=dict)
-    cookie: dict[str, Any] = field(default_factory=dict)
-    path: dict[str, Any] = field(default_factory=dict)
+    query: Mapping[str, Any] = field(default_factory=dict)
+    header: Mapping[str, Any] = field(default_factory=dict)
+    cookie: Mapping[str, Any] = field(default_factory=dict)
+    path: Mapping[str, Any] = field(default_factory=dict)
 
 
 @dataclass
